# -*- coding: utf-8 -*-
"""English language resources"""

translations = {
    "palaces": {
        "soulPalace": "Soul",
        "parentsPalace": "Parents",
        "spiritPalace": "Spirit",
        "propertyPalace": "Property",
        "careerPalace": "Career",
        "friendsPalace": "Friends",
        "surfacePalace": "Surface",
        "healthPalace": "Health",
        "wealthPalace": "Wealth",
        "childrenPalace": "Children",
        "spousePalace": "Spouse",
        "siblingsPalace": "Siblings",
    },
    "stars": {
        "major": {
            "ziweiMaj": "Ziwei",
            "tianjiMaj": "Tianji",
            "taiyangMaj": "Taiyang",
            "wuquMaj": "Wuqu",
            "tiantongMaj": "Tiantong",
            "lianzhenMaj": "Lianzhen",
            "tianfuMaj": "Tianfu",
            "taiyinMaj": "Taiyin",
            "tanlangMaj": "Tanlang",
            "jumenMaj": "Jumen",
            "tianxiangMaj": "Tianxiang",
            "tianliangMaj": "Tianliang",
            "qishaMaj": "Qisha",
            "pojunMaj": "Pojun",
        },
        "minor": {
            "zuofuMin": "Zuofu",
            "youbiMin": "Youbi",
            "wenchangMin": "Wenchang",
            "wenquMin": "Wenqu",
            "tiankuiMin": "Tiankui",
            "tianyueMin": "Tianyue",
            "huoxingMin": "Huoxing",
            "lingxingMin": "Lingxing",
            "dikongMin": "Dikong",
            "dijieMin": "Dijie",
            "lucunMin": "Lucun",
            "qingyangMin": "Qingyang",
            "tuoluoMin": "Tuoluo",
            "tianmaMin": "Tianma",
        },
    },
    "heavenlyStem": {
        "jiaHeavenly": "Jia",
        "yiHeavenly": "Yi",
        "bingHeavenly": "Bing",
        "dingHeavenly": "Ding",
        "wuHeavenly": "Wu",
        "jiHeavenly": "Ji",
        "gengHeavenly": "Geng",
        "xinHeavenly": "Xin",
        "renHeavenly": "Ren",
        "guiHeavenly": "Gui",
    },
    "earthlyBranch": {
        "ziEarthly": "Zi",
        "chouEarthly": "Chou",
        "yinEarthly": "Yin",
        "maoEarthly": "Mao",
        "chenEarthly": "Chen",
        "siEarthly": "Si",
        "wuEarthly": "Wu",
        "weiEarthly": "Wei",
        "shenEarthly": "Shen",
        "youEarthly": "You",
        "xuEarthly": "Xu",
        "haiEarthly": "Hai",
    },
    "brightness": {
        "miao": "Temple",
        "wang": "Prosperous",
        "de": "Favorable",
        "li": "Beneficial",
        "ping": "Neutral",
        "bu": "Unfavorable",
        "xian": "Trapped",
    },
}
