# -*- coding: utf-8 -*-
"""日本語言語リソース (Japanese language resources)"""

translations = {
    "palaces": {
        "soulPalace": "命宮",
        "parentsPalace": "父母宮",
        "spiritPalace": "福徳宮",
        "propertyPalace": "田宅宮",
        "careerPalace": "官禄宮",
        "friendsPalace": "交友宮",
        "surfacePalace": "遷移宮",
        "healthPalace": "疾厄宮",
        "wealthPalace": "財帛宮",
        "childrenPalace": "子女宮",
        "spousePalace": "夫妻宮",
        "siblingsPalace": "兄弟宮",
    },
    "stars": {
        "major": {
            "ziweiMaj": "紫微",
            "tianjiMaj": "天機",
            "taiyangMaj": "太陽",
            "wuquMaj": "武曲",
            "tiantongMaj": "天同",
            "lianzhenMaj": "廉貞",
            "tianfuMaj": "天府",
            "taiyinMaj": "太陰",
            "tanlangMaj": "貪狼",
            "jumenMaj": "巨門",
            "tianxiangMaj": "天相",
            "tianliangMaj": "天梁",
            "qishaMaj": "七殺",
            "pojunMaj": "破軍",
        },
        "minor": {
            "zuofuMin": "左輔",
            "youbiMin": "右弼",
            "wenchangMin": "文昌",
            "wenquMin": "文曲",
            "tiankuiMin": "天魁",
            "tianyueMin": "天鉞",
            "huoxingMin": "火星",
            "lingxingMin": "鈴星",
            "dikongMin": "地空",
            "dijieMin": "地劫",
            "lucunMin": "禄存",
            "qingyangMin": "擎羊",
            "tuoluoMin": "陀羅",
            "tianmaMin": "天馬",
        },
    },
    "heavenlyStem": {
        "jiaHeavenly": "甲",
        "yiHeavenly": "乙",
        "bingHeavenly": "丙",
        "dingHeavenly": "丁",
        "wuHeavenly": "戊",
        "jiHeavenly": "己",
        "gengHeavenly": "庚",
        "xinHeavenly": "辛",
        "renHeavenly": "壬",
        "guiHeavenly": "癸",
    },
    "earthlyBranch": {
        "ziEarthly": "子",
        "chouEarthly": "丑",
        "yinEarthly": "寅",
        "maoEarthly": "卯",
        "chenEarthly": "辰",
        "siEarthly": "巳",
        "wuEarthly": "午",
        "weiEarthly": "未",
        "shenEarthly": "申",
        "youEarthly": "酉",
        "xuEarthly": "戌",
        "haiEarthly": "亥",
    },
    "brightness": {
        "miao": "廟",
        "wang": "旺",
        "de": "得",
        "li": "利",
        "ping": "平",
        "bu": "不",
        "xian": "陷",
    },
}
